# Generated by Django 4.2.29 on 2026-03-25 02:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pipeline', '0005_assign_if_missing_groups'),
    ]

    operations = [
        migrations.AlterField(
            model_name='flowdiscordwebhook',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='flowstep',
            name='body',
            field=models.TextField(blank=True, help_text="Main body shown to the user.  Supports Markdown if the 'markdown' package is installed, otherwise rendered as plain text with line breaks.", verbose_name='body'),
        ),
        migrations.AlterField(
            model_name='flowstep',
            name='service_slug',
            field=models.CharField(blank=True, help_text="Service identifier for 'Service Account Check' steps.  Known values: discord, mumble, teamspeak.  Leave blank for other step types.", max_length=50, verbose_name='service slug'),
        ),
        migrations.AlterField(
            model_name='onboardingflow',
            name='description',
            field=models.TextField(blank=True, help_text='Short summary shown on the index and dashboard.', verbose_name='description'),
        ),
    ]
